@@ -79,29 +79,13 @@
 #' @export
 #' @seealso \code{\link{readWQPdata}}, \code{\link{whatWQPsites}}, 
 #' \code{\link{readWQPqw}}, \code{\link{constructNWISURL}}
-#' @examples
-#' site_ids <- c('04024430','04024000')
-#' startDate <- '2010-01-01'
-#' endDate <- ''
-#' parameterCd <- c('34247','30234','32104','34220')
-#' \donttest{
-#' rawNWISqwData <- readNWISqw(site_ids,parameterCd,startDate,endDate)
-#' rawNWISqwDataReshaped <- readNWISqw(site_ids,parameterCd,
-#'           startDate,endDate,reshape=TRUE)
-#' parameterCd <- "all"
-#' rawNWISall <- readNWISqw(site_ids,parameterCd,
-#'           startDate,endDate)
-#' pgroup <- c("NUT")
-#' rawNWISNutrients <- readNWISqw(site_ids,pgroup,
-#'           startDate,endDate)
-#' groups <- c("NUT","OPE")
-#' rawNWISNutOpe <- readNWISqw(site_ids,groups,
-#'           startDate,endDate) 
-#' rawISO <- readNWISqw("413144073115701", "ISO") 
-#'          } 
 readNWISqw <- function (siteNumbers,parameterCd,startDate="",endDate="",
                         expanded=TRUE,reshape=FALSE,tz="UTC"){  
   
+  .Deprecated(new = "readWQPqw", package = "dataRetrieval", 
+              msg = "NWIS qw web services are being retired. Please see the vignette 
+'Changes to NWIS QW services' for more information.")
+  
   pgrp <- c("INF", "PHY", "INM", "INN", "NUT", "MBI", "BIO", "IMM", "IMN", "TOX",
             "OPE", "OPC", "OOT", "RAD", "XXX", "SED", "POP",
             "ISO", "OTH", "HAB")
