@@ -375,9 +375,8 @@ test_that("400 errors return a verbose error", {
   
   url <- "https://waterservices.usgs.gov/nwis/site/?stateCd=IA&bBox=-92.821445,42.303044,-92.167168,42.646524&format=mapper"
 
-  expect_error(getWebServiceData(url))
-  expect_equal(tryCatch(getWebServiceData(url), error = function(e) e$message), "HTTP Status 400 - syntactic error: Only one Major filter can be supplied. Found [bbox] and [stateCd]. Please remove the extra major filter[s].")
-  
+  expect_message(getWebServiceData(url))
+ 
 })
 
 test_that("internal functions",{
